Re-exports
pub use genome::Connection;pub use genome::Genome;pub use network::activate;pub use network::Network;pub use population::Specie;pub use scenario::Hook;pub use scenario::Scenario;pub use scenario::Stats;
Modules
- crossover
- Functions related to performing measuring compatability for and performing crossover reproduction.
- genome
- Traits and impls for Genomes and their Connections.
- macros
- Macros for when it’s nice to write less code.
- network
- Traits and impls for Neural Networks derived from Genomes.
- playground
- Example scenarios for evaluating neuroevolution genomes.
- population
- Functions and structs related to managing genomes at the specie and global population scale.
- random
- Functions and structs related to RNG, random events, and mutation probabilities.
- reproduce
- Functions related to reproducing on the specie and global population scale.
- scenario
- Traits related to evaluation, fitting, and evolution of genomes for specific tasks.
Macros
- assert_
f64_ approx - assert_
matrix_ approx - assert_
some_ normalized - A macro for comparing some values who may differ in ways we don’t care about
- count
- events
- iota
- mutate_
param - new_t
- A macro for instantiating a Default-able something, and then assigning some values to it.
- normalized